@@ -123,8 +123,8 @@ void aic_score_driver(aic_struct *aic, double mle, double mleaic, nr_fmt *nr, wo
     char * savecustm;
     char *savecustm2;
 
-    savecustm = calloc (world->numpop2, sizeof (char));
-    savecustm2 = calloc (world->numpop2, sizeof (char));
+    savecustm = (char *) calloc (world->numpop2, sizeof (char));
+    savecustm2 = (char *) calloc (world->numpop2, sizeof (char));
 
     memcpy (savecustm, world->options->custm2, sizeof (char) * nr->numpop2);
     memcpy (savecustm2, world->options->custm, sizeof (char) * nr->numpop2);
@@ -181,7 +181,7 @@ void aic_print_driver(aic_fmt *aicvec, double mleaic, long aicnum, nr_fmt *nr, w
     char *temppattern;
     boolean mldone=FALSE;
     char dashes[101] = "----------------------------------------------------------------------------------------------------";
-    temppattern = calloc (world->numpop2 + 1 + world->numpop, sizeof (char));
+    temppattern = (char *) calloc (world->numpop2 + 1 + world->numpop, sizeof (char));
     FPRINTF (world->outfile,
              "%-*.*s  AIC     #param   Log(L)   LRT        Prob    Probc\n",
              (int) MAX (18, nr->partsize + nr->numpop),
@@ -232,8 +232,8 @@ akaike_information (world_fmt * world, long *Gmax)
     prepare_broyden (kind, world, &multilocus);
     world->options->migration_model = MATRIX_ARBITRARY;
 
-    temppattern = calloc (world->numpop2 + 1 + world->numpop, sizeof (char));
-    aic.param0 = calloc (world->numpop2 + 1, sizeof (double));
+    temppattern = (char *) calloc (world->numpop2 + 1 + world->numpop, sizeof (char));
+    aic.param0 = (double *) calloc (world->numpop2 + 1, sizeof (double));
 
     set_replicates (world, world->repkind, world->rep, &repstart, &repstop);
 
@@ -390,7 +390,7 @@ print_progress_aic(boolean add
     double mle, aic, lrt, prob, probcorr;
     char *temppattern;
     char *custm2 = nr->world->options->custm2;
-    temppattern = calloc (nr->world->numpop2 + 1 + nr->world->numpop, sizeof (char));
+    temppattern = (char *) calloc (nr->world->numpop2 + 1 + nr->world->numpop, sizeof (char));
     if(add
       )
     {
