@@ -9,11 +9,11 @@
  aic model  test   R O U T I N E S 
  
  Peter Beerli 2001, Seattle
- beerli@genetics.washington.edu
+ beerli@csit.fsu.edu
  
 Copyright 2001 Peter Beerli and Joseph Felsenstein
  
-$Id: aic.h,v 1.7 2003/05/31 15:10:15 beerli Exp $
+$Id: aic.h,v 1.8 2003/11/04 16:12:08 beerli Exp $
 -------------------------------------------------------*/
 #include "migration.h"
 
