@@ -34,7 +34,7 @@ inline vector float vec_float_one(void)
 inline void load_double_floatvec(FloatVec *out, double *in, long size)
 {
     long i;
-    float *tmp = calloc(size, sizeof(float));
+    float *tmp = (float *) calloc(size, sizeof(float));
     for(i=0; i < size; i++)
         tmp[i] = (float) in[i];
     memcpy(out,tmp,sizeof(float)*size);
