@@ -227,14 +227,14 @@ void bayes_init(bayes_fmt *bayes, long size)
     bayes->allocparams = 1;
     bayes->numparams = 0;
     bayes->paramnum = 0;
-    bayes->delta = calloc(size,sizeof(double));
-    bayes->minparam = calloc(size,sizeof(double));
-    bayes->maxparam = calloc(size,sizeof(double));
-    bayes->params = calloc(1,sizeof(double *));
-    bayes->params[0] = calloc(size+1,sizeof(double));
+    bayes->delta = (double *) calloc(size,sizeof(double));
+    bayes->minparam = (double *) calloc(size,sizeof(double));
+    bayes->maxparam = (double *) calloc(size,sizeof(double));
+    bayes->params = (double *) calloc(1,sizeof(double *));
+    bayes->params[0] = (double *) calloc(size+1,sizeof(double));
 
-    bayes->accept = calloc(size+1,sizeof(double));
-    bayes->trials = calloc(size+1,sizeof(double));
+    bayes->accept = (double *) calloc(size+1,sizeof(double));
+    bayes->trials = (double *) calloc(size+1,sizeof(double));
 }
 
 void bayes_fill(world_fmt *world, option_fmt *options)
@@ -294,12 +294,12 @@ void bayes_stat(world_fmt *world)
   char stemp[9];
   addon += world->options->gamma ? 1 : 0;
   size = numpop2 + addon;
-  averages = calloc(size,sizeof(double));
-  std = calloc(size,sizeof(double));
+  averages = (double *) calloc(size,sizeof(double));
+  std = (double *) calloc(size,sizeof(double));
 //  waverages = calloc(size,sizeof(double));
 //  wstd = calloc(size,sizeof(double));
-  rawstat = calloc(size,sizeof(double *));
-  rawstat[0] = calloc(size * bayes->numparams,sizeof(double));
+  rawstat = (double *) calloc(size,sizeof(double *));
+  rawstat[0] = (double *) calloc(size * bayes->numparams,sizeof(double));
   
   for(j=1; j< size; j++)
     rawstat[j] = rawstat[0] + j * bayes->numparams;
@@ -383,7 +383,7 @@ bayes_print_accept(FILE * file,  world_fmt *world)
   char *stemp;
   long tc = world->numpop2; //this ignores alpha among multiple loci
   bayes_fmt *bayes = world->bayes;
-  stemp = calloc(LINESIZE,sizeof(char));
+  stemp = (char *) calloc(LINESIZE,sizeof(char));
   FPRINTF(file,"\n\n\nAcceptance ratios for all parameters and the genealogies\n");
   FPRINTF(file,"--------------------------------------------------------\n\n");
   FPRINTF(file,"Parameter           Accepted changes            Ratio\n");
@@ -392,9 +392,9 @@ bayes_print_accept(FILE * file,  world_fmt *world)
       if(j < world->numpop)
 	{
 	  FPRINTF(file,"Theta_%-3li",j+1);
-	  FPRINTF(file, "            %8li/%-8li         %8.5f\n", bayes->accept[j],
-		  world->bayes->trials[j], 
-		  (double) bayes->accept[j]/world->bayes->trials[j]);
+	  FPRINTF(file, "            %8li/%-8li         %8.5f\n", (long) bayes->accept[j],
+		  (long) world->bayes->trials[j], 
+		   bayes->accept[j]/world->bayes->trials[j]);
 	}
       else
 	{
