@@ -4,14 +4,13 @@
 //
 // started November 2000
 // Peter Beerli Seattle 2000
-// $Id: bayes.h,v 1.6 2002/07/05 22:14:24 beerli Exp $
+// $Id: bayes.h,v 1.7 2003/10/21 15:57:52 beerli Exp $
 //
 #include "migration.h"
 #ifdef BAYESUPDATE
 extern boolean acceptBayes (double newval, double oldval);
-extern double propose_newparam (double param,
-                                    double delta,
-                                    double minparam, double maxparam);
+extern double propose_uni_newparam (double param, double delta, double minparam, double maxparam);
+extern double propose_exp_newparam (double param, double delta, double minparam, double maxparam);
 extern long bayes_update (world_fmt *world);
 extern void bayes_free(world_fmt *world);
 extern void bayes_fill(world_fmt *world, option_fmt *options);
