@@ -1198,7 +1198,7 @@ gradient (double *d, nr_fmt * nr, long locus)
     double *normalgrad;
     double mu_rate = nr->world->options->mu_rates[locus];
     double inv_mu_rate = 1. / mu_rate;
-    normalgrad = malloc(nr->numpop2 * sizeof(double));
+    normalgrad = (double*) malloc(nr->numpop2 * sizeof(double));
     memset (d, 0, sizeof (double) * nr->numpop2);
     thetas = nr->param;
     m = nr->param + numpop;
@@ -1305,7 +1305,7 @@ gradient_longsum (double *d, nr_fmt * nr, long locus)
     double timeinterval;
     //interval[0]=intervals[1]=intervals[2]=0;
     FPRINTF(stdout,"rawrates=%f %f %f @ %f %f %f \n",rawrates[0],rawrates[1],rawrates[2],rawrates[3],rawrates[4],rawrates[5]);
-    treeparts = calloc(nr->numpop2+numpop3,sizeof(double));
+    treeparts = (double *) calloc(nr->numpop2+numpop3,sizeof(double));
     memset (d, 0, sizeof (double) * nr->partsize);
     thetas = nr->param;
     m = nr->param + numpop;
@@ -1756,7 +1756,7 @@ probG_longsum (double *param, double *lparam, tarchive_fmt * tl, nr_fmt * nr,
     longsum_fmt *tint;
     double *sm;
 
-    sm = calloc(nr->numpop, sizeof(double));
+    sm = (double *) calloc(nr->numpop, sizeof(double));
     for(pop=0;pop<nr->numpop; pop++)
     {
         for (i = nr->world->mstart[pop]; i < nr->world->mend[pop]; i++)
