@@ -13,7 +13,7 @@
  
  
  Peter Beerli 1996-1998, Seattle
- beerli@genetics.washington.edu
+ beerli@csit.fsu.edu
  
  
     Copyright 2001 Peter Beerli and Joseph Felsenstein
@@ -23,7 +23,7 @@
  works and are not responsible for any damage you may cause or have.
  
  
-$Id: combroyden2.c,v 1.87 2003/06/10 15:55:19 beerli Exp $
+$Id: combroyden2.c,v 1.89 2003/11/04 16:12:08 beerli Exp $
  
 -------------------------------------------------------*/
 
@@ -196,6 +196,10 @@ estimateParameter (long rep, long G, world_fmt * world, option_fmt * options,
 
     boolean multilocus;
     nr_fmt *nr;
+#ifdef BAYESUPDATE
+    if (world->options->bayes_infer)
+        return -1; //when we run in Baysian mode we do not need to maximuze the likelihood
+#endif
     nr = (nr_fmt *) calloc (1, sizeof (nr_fmt));
     if (kind == MULTILOCUS)
     {
