@@ -430,7 +430,7 @@ read_sites (data_fmt * data)
 {
     long locus;
     char *input;
-    input = calloc(LINESIZE,sizeof(char));
+    input = (char *) calloc(LINESIZE,sizeof(char));
     
     for (locus = 0; locus < data->loci-1; locus++)
     {
@@ -953,8 +953,8 @@ print_data_summary (FILE * file, world_fmt * world, option_fmt * options,
     char dstring[LINESIZE];
     long *total;
     long *totalmiss;
-    total = calloc(data->loci,sizeof(long));
-    totalmiss = calloc(data->loci,sizeof(long));
+    total = (long *) calloc(data->loci,sizeof(long));
+    totalmiss = (long *) calloc(data->loci,sizeof(long));
     fprintf (file, "Summary of data:\n");
     fprintf (file, "---------------\n");
     switch (options->datatype)
