@@ -22,11 +22,11 @@ $Id: definitions.h,v 1.85 2003/11/19 03:52:37 beerli Exp $
   *----------------------------------------------------------------
   */
 #ifndef MIGRATEVERSION
-#define MIGRATEVERSION "1.7.6"
+#define MIGRATEVERSION "1.7.6.1"
 #else
 #ifdef SGI
 #undef MIGRATEVERSION
-#define MIGRATEVERSION "1.7.6"
+#define MIGRATEVERSION "1.7.6.1"
 #endif
 #endif
 
@@ -385,6 +385,7 @@ long chains is used */
 #define LASTCHAIN              3 /*+ */
 /* likelihood ration stuff*/
 #define LRATIO_STRINGS      1000 /*+ */
+#define HUNDRED              100
 /* profile likelihood stuff*/
 /* ALL and NONE are alread defined*/
 #define TABLES                 2 /*+ */
