@@ -8,7 +8,7 @@ using a Metropolis-Hastings Monte Carlo algorithm
  calculates FST
  
  Peter Beerli 1996, Seattle
- beerli@genetics.washington.edu
+ beerli@csit.fsu.edu
  
  Copyright 2001 Peter Beerli and Joseph Felsenstein
  
@@ -17,7 +17,7 @@ using a Metropolis-Hastings Monte Carlo algorithm
  works and are not responsible for any damage you may cause or have.
  
  
-$Id: fst.c,v 1.20 2002/06/20 06:25:34 beerli Exp $
+$Id: fst.c,v 1.21 2003/11/04 16:12:08 beerli Exp $
  
 -------------------------------------------------------*/
 
