@@ -12,11 +12,11 @@
  
  
  Peter Beerli 1996, Seattle
- beerli@genetics.washington.edu
+ beerli@csit.fsu.edu
  
 Copyright 2001 Peter Beerli and Joseph Felsenstein
  
-$Id: fst.h,v 1.5 2002/06/20 06:25:34 beerli Exp $
+$Id: fst.h,v 1.6 2003/11/04 16:12:08 beerli Exp $
 -------------------------------------------------------*/
 extern void fst_type (char type);
 extern void calc_fst (world_fmt * world, data_fmt * data);
