@@ -304,7 +304,7 @@ void adjust_temperatures(world_fmt ** universe, long hchains, long step, long st
         if ( (step % HEATCHECKINTERVAL ) == 0)
         {
             universe[0]->averageheat= 1.0;
-            delta = calloc(hchains,sizeof(double));
+            delta = (double *) calloc(hchains,sizeof(double));
 	    // FPRINTF(stdout,"\n%f %li\n",1./universe[0]->heat,universe[0]->treeswapcount);
             for(i=1; i< hchains; i++)
             {
