@@ -8,11 +8,11 @@
  Laguerre integration  R O U T I N E S 
  
  Peter Beerli 2000, Seattle
- beerli@genetics.washington.edu
+ beerli@csit.fsu.edu
  
 Copyright 2001 Peter Beerli and Joseph Felsenstein
  
-$Id: laguerre.h,v 1.5 2002/06/20 06:25:35 beerli Exp $
+$Id: laguerre.h,v 1.6 2003/11/04 16:12:08 beerli Exp $
 -------------------------------------------------------*/
 
 extern void integrate_laguerre (long categs, double *rate,
