@@ -467,7 +467,10 @@ void print_lrt_box(world_fmt *world, double *param0, double *param1, long zeros,
     double aic = -2. * like0 + 2. * aicparamnum;
 
     char **box;
-    long size = 8; // we need at least 7 lines to print the right side of the table
+    long size = HUNDRED; // we need at least 7 lines to print 
+    //the right side of the table, but for some large dataset this breaks
+    //sloppy fix, in version 1.8 this needs to be fixed correctly
+    //the reallocation algorithm seems to miss lines
     long newsize;
     long i;
     
@@ -476,7 +479,7 @@ void print_lrt_box(world_fmt *world, double *param0, double *param1, long zeros,
     print_line(world->outfile,'-',79,CONT);
     box = (char **) calloc (size, sizeof (char *));
     for(i=0; i<size; i++)
-        box[i] = calloc(LRATIO_STRINGS,sizeof(char));
+        box[i] = (char *) calloc(LRATIO_STRINGS,sizeof(char));
     newsize = parse_h0(&box,&size, this_string1,param0,param1,elem,world);
     print_box(world,box,newsize,like0,like1,testval, chiprob, chiprob2, aic, df, aicparamnum);
     if(world->options->progress)
@@ -528,7 +531,7 @@ void parse_h0part(char ***box, long *size, long *tempsize,
         if (counter + length > BOXSIZE)
         {
             (*tempsize)++;
-            if(*tempsize>= *size)
+            if(*tempsize>= *size-1)
               {
                 *box = (char **) realloc(*box,sizeof(char*) * (*tempsize+1));
                 (*box)[*tempsize] = (char *) calloc(LRATIO_STRINGS,sizeof(char));
@@ -552,7 +555,7 @@ void parse_h0string(char ***box, long *size, long *tempsize,
         if (counter >= BOXSIZE)
           {
             (*tempsize)++;
-            if(*tempsize>= *size)
+            if(*tempsize>= *size-1)
               {
                 *box = (char **) realloc(*box,sizeof(char*) * (*tempsize+1));
                 (*box)[*tempsize] = (char *) calloc(LRATIO_STRINGS,sizeof(char));
@@ -887,7 +890,7 @@ long simplify_lrtvalues(char * in, char*** out)
 {
     long elements=0;
     long count = 0;
-    (*out)[0] = calloc(LONGLINESIZE,sizeof(char));
+    (*out)[0] = (char *) calloc(LONGLINESIZE,sizeof(char));
     while(*in!='\0')
       {
         switch(*in)
@@ -901,7 +904,7 @@ long simplify_lrtvalues(char * in, char*** out)
             case ';':
                 count=0;
                 elements++;
-                (*out)[elements] = calloc(LONGLINESIZE,sizeof(char));
+                (*out)[elements] = (char *) calloc(LONGLINESIZE,sizeof(char));
                 break;
             default:
                 (*out)[elements][count++] = *in;
