@@ -9,11 +9,11 @@
  
  moved out from world.c                                                                                                               
  Peter Beerli 2000, Seattle
- beerli@genetics.washington.edu
+ beerli@csit.fsu.edu
  
 Copyright 2001 Peter Beerli and Joseph Felsenstein
  
-$Id: lrt.h,v 1.6 2002/10/23 22:43:42 beerli Exp $
+$Id: lrt.h,v 1.7 2003/11/04 16:12:08 beerli Exp $
 -------------------------------------------------------*/
 
 extern void print_lratio_test (world_fmt * world, long *Gmax);
