@@ -245,8 +245,8 @@ main(int argc, char **argv)
 //debug fprintf(stdout,"==> SINGLE CPU VERSION <==\n");
 #endif
     //random number seed global inits
-    seed = malloc(sizeof(long) * 3);
-    newseed = malloc(sizeof(long) * 3);
+    seed = (long *) malloc(sizeof(long) * 3);
+    newseed = (long *) malloc(sizeof(long) * 3);
     //
     universe = (world_fmt **) calloc(HEATED_CHAIN_NUM, sizeof(world_fmt *));
     this_string = (char *) calloc(1, sizeof(char) * 256);
