@@ -11,11 +11,11 @@
  
  
  Peter Beerli 1996, Seattle
- beerli@genetics.washington.edu
+ beerli@csit.fsu.edu
  
 Copyright 2001 Peter Beerli and Joseph Felsenstein
  
-$Id: mcmc.h,v 1.5 2002/06/20 06:25:35 beerli Exp $
+$Id: mcmc.h,v 1.6 2003/11/04 16:12:09 beerli Exp $
 -------------------------------------------------------*/
 
 extern long tree_update (world_fmt * world, long g);
