@@ -9,7 +9,7 @@
  
  
  Peter Beerli 1996, Seattle
- beerli@genetics.washington.edu
+ beerli@csit.fsu.edu
  
 Copyright 2001 Peter Beerli and Joseph Felsenstein
  
@@ -17,7 +17,7 @@ Copyright 2001 Peter Beerli and Joseph Felsenstein
  and is copyrighted. Of course, we do not guarantee that the software
  works and are not responsible for any damage you may cause or have.
  
-$Id: mcmc1.c,v 1.64 2003/05/22 20:59:18 beerli Exp $
+$Id: mcmc1.c,v 1.67 2003/11/04 16:12:09 beerli Exp $
 -------------------------------------------------------*/
 #include "migration.h"
 #include "random.h"
@@ -38,6 +38,7 @@ $Id: mcmc1.c,v 1.64 2003/05/22 20:59:18 beerli Exp $
 #define NO_MIGR_NODES 0
 #define WITH_MIGR_NODES 1
 
+extern node * showtop();
 /* prototypes ------------------------------------------- */
 // metropolize over trees
 long tree_update (world_fmt * world, long g);
@@ -178,7 +179,7 @@ tree_update (world_fmt * world, long g)
             {
                 if (!migrate (proposal, proposal->origin))
                 {
-                    free_proposal (proposal);
+		  //                    free_proposal (proposal);
                     free_timevector (timevector);
                     return 0;
                 }
@@ -208,8 +209,12 @@ tree_update (world_fmt * world, long g)
         if (!pre_population
                 (proposal, (*timevector).tl, (*timevector).T - 1, &slider))
         {
-            free_proposal (proposal);
+	  //            free_proposal (proposal);
             free_timevector (timevector);
+#ifdef BAYESUPDATE
+	    if(world->options->verbose)
+	      FPRINTF(stdout,"   \n");
+#endif
             return 0;
         }
         pretendcoalesce1p (proposal);
@@ -255,10 +260,18 @@ tree_update (world_fmt * world, long g)
         count_migrations (world->root->next->back, &world->migration_counts);
         free_proposal (proposal);
         free_timevector (timevector);
+#ifdef BAYESUPDATE
+	    if(world->options->verbose)
+	      FPRINTF(stdout,"***\n");
+#endif
         return 1;   /* new tree accepted */
     }
     free_proposal (proposal);
     free_timevector (timevector);
+#ifdef BAYESUPDATE
+	    if(world->options->verbose)
+	      FPRINTF(stdout,"   \n");
+#endif
     return 0;   /* not accepted */
 
 }
@@ -283,18 +296,20 @@ new_localtimelist (timelist_fmt ** ntl, timelist_fmt * otl, long numpop)
     }
 }
 
+
+
 void
 new_proposal (proposal_fmt ** proposal, timelist_fmt * tl, world_fmt * world)
 {
     long j;
     long mal = world->data->maxalleles[world->locus];
-    (*proposal) = (proposal_fmt *) calloc (1, sizeof (proposal_fmt));
-    (*proposal)->listsize = ((*tl).allocT + (*tl).T + 5);
+    long listsize = ((*tl).allocT + (*tl).T + 5);
+    long sumtips = world->sumtips;
 
-    (*proposal)->aboveorigin =
-        (node **) calloc (1, sizeof (node *) * (*proposal)->listsize);
-    (*proposal)->bordernodes =
-        (node **) calloc (1, sizeof (node *) * (*proposal)->listsize);
+    // allocate the scratchpad (contains a shadow of the tree)
+    (*proposal) = (proposal_fmt *) calloc (1, sizeof (proposal_fmt));
+
+    // pointers and values to outside structures
     (*proposal)->world = world;
     (*proposal)->datatype = world->options->datatype;
     (*proposal)->sumtips = world->sumtips;
@@ -304,12 +319,27 @@ new_proposal (proposal_fmt ** proposal, timelist_fmt * tl, world_fmt * world)
     (*proposal)->param0 = world->param0;
     (*proposal)->root = world->root;
     (*proposal)->migration_model = world->options->migration_model;
-    (*proposal)->line_f =
-        (node **) calloc (1, sizeof (node *) * (*proposal)->sumtips);
-    (*proposal)->line_t =
-        (node **) calloc (1, sizeof (node *) * (*proposal)->sumtips);
-    (*proposal)->mf = (double *) calloc ((*proposal)->endsite, sizeof (double));
-    (*proposal)->mt = (double *) calloc ((*proposal)->endsite, sizeof (double));
+    // precalculated values
+    (*proposal)->mig0list = world->mig0list;
+    (*proposal)->design0list = world->design0list;
+    
+    (*proposal)->listsize =  listsize;
+
+    // node data holding vector for aboveorigin, bordernodes, line_f, line_t
+    (*proposal)->nodedata =
+        (node **) calloc (2 * listsize + 2 * sumtips, sizeof (node *));
+    // nodes above the picked node
+    (*proposal)->aboveorigin = (*proposal)->nodedata;
+    // adjacent nodes of the pcked nodes
+    (*proposal)->bordernodes = (*proposal)->nodedata + listsize;
+    // line_f nodes
+    (*proposal)->line_f =   (*proposal)->nodedata + listsize + sumtips;
+    (*proposal)->line_t =  (*proposal)->nodedata + listsize + 2 * sumtips;
+
+    // mf holds also mt array  
+    (*proposal)->mf = (double *) calloc (2* (*proposal)->endsite, sizeof (double));
+    (*proposal)->mt = (*proposal)->mf + (*proposal)->endsite;
+
     if (strchr (SEQUENCETYPES, (*proposal)->datatype))
     {
         (*proposal)->xf.s =
@@ -329,8 +359,8 @@ new_proposal (proposal_fmt ** proposal, timelist_fmt * tl, world_fmt * world)
         (*proposal)->xf.a = (double *) calloc (1, sizeof (double) * mal);
         (*proposal)->xt.a = (double *) calloc (1, sizeof (double) * mal);
     }
-    (*proposal)->old_migr_table_counter = 4 * (*proposal)->sumtips /* 100 */ ;
-    (*proposal)->old_migr_table_counter2 = 4 * (*proposal)->sumtips /* 100 */ ;
+    (*proposal)->old_migr_table_counter = 4 * sumtips /* 100 */ ;
+    (*proposal)->old_migr_table_counter2 = 4 * sumtips /* 100 */ ;
     (*proposal)->migr_table =
         (migr_table_fmt *) calloc (1,
                                    sizeof (migr_table_fmt) *
@@ -340,9 +370,6 @@ new_proposal (proposal_fmt ** proposal, timelist_fmt * tl, world_fmt * world)
                                    sizeof (migr_table_fmt));
     (*proposal)->migr_table_counter = 0;
     (*proposal)->migr_table_counter2 = 0;
-    // precalculated values
-    (*proposal)->mig0list = world->mig0list;
-    (*proposal)->design0list = world->design0list;
 #ifdef UEP
 
     if (world->options->uep)
@@ -1046,12 +1073,13 @@ void
 free_proposal (proposal_fmt * proposal)
 {
     long j;
-    free (proposal->aboveorigin);
-    free (proposal->bordernodes);
-    free (proposal->line_f);
-    free (proposal->line_t);
+    free(proposal->nodedata);
+   // free (proposal->aboveorigin);
+    // free (proposal->bordernodes);
+    // free (proposal->line_f);
+    // free (proposal->line_t);
     free (proposal->mf);
-    free (proposal->mt);
+   // free (proposal->mt);
     if (strchr (SEQUENCETYPES, proposal->datatype))
     {
         for (j = 0; j < proposal->endsite; j++)
