@@ -13,11 +13,11 @@
  
  
  Peter Beerli 1996, Seattle
- beerli@genetics.washington.edu
+ beerli@csit.fsu.edu
  
 Copyright 2001 Peter Beerli and Joseph Felsenstein
  
-$Id: mcmc2.h,v 1.2 2001/06/02 21:40:21 beerli Exp $
+$Id: mcmc2.h,v 1.4 2003/11/04 16:12:09 beerli Exp $
 -------------------------------------------------------*/
 
 extern void coalesce1p (proposal_fmt * proposal);
