@@ -9,11 +9,11 @@
  
  presents the menu and its submenus.                                                                                                               
  Peter Beerli 1996, Seattle
- beerli@genetics.washington.edu
+ beerli@csit.fsu.edu
  
 Copyright 2001 Peter Beerli and Joseph Felsenstein
  
-$Id: menu.h,v 1.8 2002/08/12 21:13:54 beerli Exp $
+$Id: menu.h,v 1.9 2003/11/04 16:12:09 beerli Exp $
 -------------------------------------------------------*/
 
 #include "migration.h"
