@@ -494,8 +494,7 @@ setup_mighist (world_fmt * world, option_fmt * options)
     long allocsize = DEFAULTALLOCSIZE;
     if (world->options->mighist)
     {
-        world->mighistloci = (mighistloci_fmt *)
-                             calloc (world->loci, sizeof (mighistloci_fmt));
+        world->mighistloci = (mighistloci_fmt *) calloc (world->loci, sizeof (mighistloci_fmt));
         world->mighistlocinum = 0;
         for (locus = 0; locus < world->loci; locus++)
         {
