@@ -2002,7 +2002,7 @@ void set_filehandle(char *message, world_fmt *world,
     long filepos=0;
     static char *temp;
     long filenum;
-    temp = calloc(100,sizeof(char));
+    temp = (char *) calloc(100,sizeof(char));
     filepos = strcspn(message,":") + 1;
     *msgstart = filepos;
     strncpy(temp,message,filepos);
@@ -2037,7 +2037,7 @@ mpi_fprintf(FILE *file, const char *fmt, ...)
     va_list ap;
     long filehandle = 0;
     long bufsize = 0;
-    p = calloc(MAXBUFSIZE,sizeof(char));
+    p = (char *) calloc(MAXBUFSIZE,sizeof(char));
     if(myID!=MASTER)
     {
         filehandle = retrieve_filehandle(file);
