@@ -1,7 +1,11 @@
 #ifndef __MIGRATE_MPI_
 #define __MIGRATE_MPI_
 #ifdef MPI
+#ifdef POOCH
+#include "pooch_mpi.h"
+#else
 #include <mpi.h>
+#endif
 #include "migration.h"
 
 #include <stdarg.h>
