@@ -10,7 +10,7 @@
   Genetics 357730
   University of Washington
   Seattle, WA 98195-7730, USA
-  beerli@gs.washington.edu
+  beerli@csit.fsu.edu
  
  copyright 2002 Peter Beerli and Joseph Felsenstein. 
   *----------------------------------------------------------------
@@ -156,6 +156,8 @@ typedef struct _bayes
     long numparams;  //number of saved parameter vectors
     long paramnum;  // which param one is working with
     double oldval;    //holds prob(G|param)
+  long *accept;  //holds numbers of accepted changes for each parameter AND the tree
+  long *trials; //holds how many time was tried to change a parameter
 }
 bayes_fmt;
 #endif
@@ -301,7 +303,7 @@ typedef struct _option
     long saveseed;
     /* mcmc options */
     boolean bayes_infer;
-	double updateratio;
+    double updateratio;
 #ifdef BAYESUPDATE
 
     bayes_fmt *bayes;
@@ -571,6 +573,7 @@ typedef struct _worldoption
     boolean simulation;
     char datatype;
     long lsteps;
+    long lincr;
     double loglsteps;
     long treeprint;
     long movingsteps;
@@ -658,6 +661,8 @@ typedef struct _worlddata
 }
 worlddata_fmt;
 
+//typedef struct _proposal_fmt proposal_fmt;
+
 typedef struct _world
 {
     /* generalities */
@@ -665,6 +670,8 @@ typedef struct _world
     char *worldname;
     worldoption_fmt *options;
     worlddata_fmt *data;
+
+    //proposal_fmt  *proposal;  
 #ifdef MPI
 
     int *who;
@@ -870,21 +877,27 @@ typedef struct _migr_table_fmt
 }
 migr_table_fmt;
 
-typedef struct proposal_fmt
+typedef  struct _proposal_fmt
 {
     world_fmt *world;
-    boolean mig_removed;
     char datatype;
-    short migration_model;
     long sumtips;
     long numpop;
     long endsite;
     double fracchange;
     double *param0;
-    double rr;
     node *root;
-    node *origin;
-    node *target;
+    short migration_model;
+
+    long listsize; // holds the size of several nodelists
+
+    
+    boolean mig_removed;
+
+    double rr;
+    node **nodedata;      // holds abovenodes and bordernodes
+    node *origin;            // pointers into nodedata
+    node *target;            // .... 
     node *realtarget;
     node *tsister;
     node *realtsister;
@@ -918,7 +931,6 @@ typedef struct proposal_fmt
 
     node **aboveorigin;
     node **bordernodes;
-    long listsize;
     migr_table_fmt *migr_table;
     migr_table_fmt *migr_table2;
     long migr_table_counter;
@@ -929,8 +941,7 @@ typedef struct proposal_fmt
     double *mig0list;
     long *design0list;
     double treelen;
-}
-proposal_fmt;
+} proposal_fmt;
 
 typedef struct spline_fmt
 {
