@@ -727,8 +727,10 @@ prognose_profile_end (time_t starttime, long numpop2, long nn)
     }
     else
         tally++;
-#endif
+
     free(nowstr);
+#endif
+
 }
 
 
@@ -1163,8 +1165,7 @@ set_profile_param (double *param, long which, long *allwhich,
     {
         has_fixed = TRUE;
         fixed =
-            (long *)
-                calloc (1,
+            (long *) calloc (1,
                         sizeof (long) * (numpop2 +
                                          (long) world->options->gamma));
         p = world->options->custm2;
