@@ -6,11 +6,11 @@
  P R O F I L E    L I K E L I H O O D    R O U T I N E S 
  
  Peter Beerli 1997, Seattle
- beerli@genetics.washington.edu
+ beerli@csit.fsu.edu
  
 Copyright 2001 Peter Beerli and Joseph Felsenstein
  
-$Id: profile.h,v 1.9 2002/06/20 06:25:37 beerli Exp $
+$Id: profile.h,v 1.10 2003/11/04 16:12:09 beerli Exp $
 -------------------------------------------------------*/
 extern boolean print_profile_likelihood_driver (long which, world_fmt * world,
             long *gmaxptr);
