@@ -7,7 +7,7 @@
  
  
  Peter Beerli 1996, Seattle
- beerli@genetics.washington.edu
+ beerli@csit.fsu.edu
  
  Copyright 2002 Peter Beerli and Joseph Felsenstein
  
@@ -16,7 +16,7 @@
  works and are not responsible for any damage you may cause or have.
  
  
- $Id: sequence.c,v 1.45 2003/06/10 15:55:20 beerli Exp $
+ $Id: sequence.c,v 1.47 2003/11/04 16:12:09 beerli Exp $
  
 -------------------------------------------------------*/
 
@@ -375,7 +375,8 @@ getbasefreqs (option_fmt * options, seqmodel_fmt * seq, long locus)
         printf ("  so transition/transversion ratio is %10.6f\n\n",
                 (seq->ttratio));
     }
-    seq->fracchange =
+    // use 1/frac as precomputation speed up
+    seq->fracchange = 1. / (
         (seq->xi) * (2 * seq->freqa * (seq->freqgr) +
                      2 * seq->freqc * (seq->freqty)) + (seq->xv) * (1.0 -
                              seq->freqa *
@@ -385,7 +386,7 @@ getbasefreqs (option_fmt * options, seqmodel_fmt * seq, long locus)
                              seq->freqg *
                              seq->freqg -
                              seq->freqt *
-                             seq->freqt);
+                             seq->freqt));
 }
 
 /*===================================================*/
