@@ -9,11 +9,11 @@
  
  
  Peter Beerli 1996, Seattle
- beerli@genetics.washington.edu
+ beerli@csit.fsu.edu
  
 Copyright 2001 Peter Beerli and Joseph Felsenstein
  
-$Id: sequence.h,v 1.13 2002/06/20 06:25:38 beerli Exp $
+$Id: sequence.h,v 1.14 2003/11/04 16:12:10 beerli Exp $
 -------------------------------------------------------*/
 
 extern void initratio (option_fmt * options);
