@@ -246,7 +246,7 @@ init_files (world_fmt * world, data_fmt * data, option_fmt * options)
 	long i,j;
 #endif
     long maxfilenum = 41; //20*2+1;
-	tempdb = calloc(maxfilenum,sizeof(long));
+	tempdb = (long *) calloc(maxfilenum,sizeof(long));
 	
     if (myID == MASTER)
     {
